==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/PagerDutyLinkConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PagerDutyLinkConfigFluent<A extends PagerDutyLinkConfigFluent<A>> extends BaseFluent<A>{
  public PagerDutyLinkConfigFluent() {
  }
  public PagerDutyLinkConfigFluent(PagerDutyLinkConfig instance) {
    instance = (instance != null ? instance : new PagerDutyLinkConfig());

    if (instance != null) {
      this.withAlt(instance.getAlt());
      this.withHref(instance.getHref());
      this.withAlt(instance.getAlt());
      this.withHref(instance.getHref());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String alt;
  private String href;
  private Map<String,Object> additionalProperties;
  public String getAlt() {
    return this.alt;
  }
  public A withAlt(String alt) {
    this.alt=alt; return (A) this;
  }
  public boolean hasAlt() {
    return this.alt != null;
  }
  public String getHref() {
    return this.href;
  }
  public A withHref(String href) {
    this.href=href; return (A) this;
  }
  public boolean hasHref() {
    return this.href != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PagerDutyLinkConfigFluent that = (PagerDutyLinkConfigFluent) o;
    if (!java.util.Objects.equals(alt, that.alt)) return false;

    if (!java.util.Objects.equals(href, that.href)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(alt,  href,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (alt != null) { sb.append("alt:"); sb.append(alt + ","); }
    if (href != null) { sb.append("href:"); sb.append(href + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-monitoring-6.9.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/PagerDutyLinkConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PagerDutyLinkConfigFluent<A extends PagerDutyLinkConfigFluent<A>> extends BaseFluent<A>{
  public PagerDutyLinkConfigFluent() {
  }
  
  public PagerDutyLinkConfigFluent(PagerDutyLinkConfig instance) {
    this.copyInstance(instance);
  }
  private String alt;
  private String href;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PagerDutyLinkConfig instance) {
    instance = (instance != null ? instance : new PagerDutyLinkConfig());
    if (instance != null) {
          this.withAlt(instance.getAlt());
          this.withHref(instance.getHref());
          this.withAlt(instance.getAlt());
          this.withHref(instance.getHref());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAlt() {
    return this.alt;
  }
  
  public A withAlt(String alt) {
    this.alt = alt;
    return (A) this;
  }
  
  public boolean hasAlt() {
    return this.alt != null;
  }
  
  public String getHref() {
    return this.href;
  }
  
  public A withHref(String href) {
    this.href = href;
    return (A) this;
  }
  
  public boolean hasHref() {
    return this.href != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PagerDutyLinkConfigFluent that = (PagerDutyLinkConfigFluent) o;
    if (!java.util.Objects.equals(alt, that.alt)) return false;
    if (!java.util.Objects.equals(href, that.href)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(alt,  href,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (alt != null) { sb.append("alt:"); sb.append(alt + ","); }
    if (href != null) { sb.append("href:"); sb.append(href + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
